# VideoFlow

## Original code

[https://github.com/XiaoyuShi97/VideoFlow](https://github.com/XiaoyuShi97/VideoFlow)

## Code license

Apache License.

## Pretrained weights license

Not specified.

## Citation

```
@inproceedings{shi2023videoflow,
  title={Videoflow: Exploiting temporal cues for multi-frame optical flow estimation},
  author={Shi, Xiaoyu and Huang, Zhaoyang and Bian, Weikang and Li, Dasong and Zhang, Manyuan and Cheung, Ka Chun and See, Simon and Qin, Hongwei and Dai, Jifeng and Li, Hongsheng},
  booktitle={ICCV},
  year={2023}
}
```